@@ -1,3 +1,4 @@
+from typing import Tuple
 from flask import Flask
 import flask
 from flask import request
@@ -221,15 +222,17 @@ def run():
     app.run(host="localhost", port=port)
 
 
-def find_arg(args, flag):
+def find_arg(args, flag, return_value=True):
     try:
         idx = args.index(flag)
-        find = args[idx+1]
-        return find
-    except IndexError:
+
+        if return_value:
+            return True, args[idx+1]
+        return idx >= 0, None
+    except ValueError:
         pass
 
-    return None
+    return False, None
 
 
 def start_update():
@@ -245,12 +248,12 @@ def start_update():
 def main():
     args = sys.argv
 
-    dir = find_arg(args, '-dir')
-    if dir:
+    has, dir = find_arg(args, '-dir')
+    if has:
         os.chdir(dir)
 
-    update = find_arg(args, '-u')
-    if update:
+    has, _ = find_arg(args, '-u', return_value=False)
+    if has:
         start_update()
 
     run()
